package com.scipanama.photoUploader.activities;

import java.io.File;

import roboguice.inject.ContentView;
import roboguice.inject.InjectView;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.provider.MediaStore;
import android.util.Log;
import android.view.View;
import android.widget.GridView;

import com.actionbarsherlock.view.Menu;
import com.actionbarsherlock.view.MenuItem;
import com.github.rtyley.android.sherlock.roboguice.activity.RoboSherlockFragmentActivity;
import com.google.inject.Inject;
import com.scipanama.photoUploader.R;
import com.scipanama.photoUploader.dialogs.ConfirmUploadDialog;
import com.scipanama.photoUploader.platform.FileInterface;
import com.scipanama.photoUploader.platform.ImageAdapter;

/**
 * @author zubietaroberto
 *
 */
@ContentView(R.layout.activity_gallery)
public class GalleryActivity extends RoboSherlockFragmentActivity{	

	public static final String sKey_Reference = "REFERENCE";
	
	private static final String TAG = "GalleryActivity";
	private static final String TAG_PREAMBLE = TAG.concat(" >==< ");
	
	private String mReference = null;
	private ImageAdapter mAdapter = null;
	
	@Inject private FileInterface mFileInterface;
	
	@InjectView(R.id.activity_gallery_gridview) 		private GridView mGridView;
	@InjectView(R.id.activity_gallery_gridview_empty)	private View mEmpty;

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		
		//Basic Setup
	    super.onCreate(savedInstanceState);
	    
	    //Get the Reference Number
	    final Bundle extras = this.getIntent().getExtras();
	    if (extras == null){
	    	Log.e(TAG, TAG_PREAMBLE.concat("no Bundle extras!"));
	    	this.finish();
	    }
	    
	    //Get Values
	    this.mReference = extras.getString(sKey_Reference);
	    this.setTitle(mReference);
	    
	    //Set Adapter
	    this.mAdapter = new ImageAdapter(this, mReference);
	    mGridView.setAdapter(this.mAdapter);
	    mGridView.setEmptyView(mEmpty);
	}

	@Override
	protected void onResume() {
		
		super.onResume();	    
	    
	    //Load Images
	    this.mAdapter.notifyDataSetChanged();
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		this.getSupportMenuInflater().inflate(R.menu.activity_gallery, menu);
		this.getSupportActionBar().setDisplayHomeAsUpEnabled(true);
		return super.onCreateOptionsMenu(menu);
	}

	
	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		
		switch (item.getItemId()){
		
		//Android Home-Up Button
		case android.R.id.home:
			final Intent homeIntent = new Intent(this, MainActivity.class);
			homeIntent.addFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP);
			this.startActivity(homeIntent);
			return true;
		
		//Add new photo
		case R.id.menu_gallery_add:
			final File photo = this.mFileInterface.createPictureFile(mReference);
			
			//If there was an error cancel the launch...
			if(photo == null){
				return true;
			}
			
			//Launch camera Activity
			final Intent intent = new Intent(MediaStore.ACTION_IMAGE_CAPTURE);
			intent.putExtra(MediaStore.EXTRA_OUTPUT, Uri.fromFile(photo));
			this.startActivity(intent);		

			return true;
		
		//Accept & Upload all photos
		case R.id.menu_gallery_accept:
			
			final Bundle data = new Bundle();
			data.putString(ConfirmUploadDialog.sReference, mReference);
			
			//Launch dialog to confirm upload
			final ConfirmUploadDialog cud = new ConfirmUploadDialog();
			cud.setArguments(data);
			cud.show(getSupportFragmentManager(), "Confirm Upload Dialog");
			
			return true;
		}
		
		return false;
		
		
	}

}
