package com.scipanama.photoUploader.activities;

import org.json.JSONException;
import org.json.JSONObject;

import roboguice.inject.ContentView;
import roboguice.inject.InjectResource;
import roboguice.inject.InjectView;
import android.accounts.Account;
import android.accounts.AccountAuthenticatorResponse;
import android.accounts.AccountManager;
import android.content.ContentResolver;
import android.os.Bundle;
import android.support.v4.app.LoaderManager.LoaderCallbacks;
import android.support.v4.content.Loader;
import android.text.TextUtils;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.ProgressBar;
import android.widget.Toast;

import com.github.rtyley.android.sherlock.roboguice.activity.RoboSherlockFragmentActivity;
import com.google.common.base.Preconditions;
import com.google.inject.Inject;
import com.scipanama.photoUploader.R;
import com.scipanama.photoUploader.auth.Authenticator;
import com.scipanama.photoUploader.dialogs.MessageDialog;
import com.scipanama.photoUploader.json.AuthTokenLoader;

/**
 * @author zubietaroberto
 *
 */

@ContentView(R.layout.activity_login)
public class LoginActivity extends RoboSherlockFragmentActivity 
implements OnClickListener, LoaderCallbacks<JSONObject> {

	private static final String sKey_Username = "USERNAME";
	private static final String sKey_Password = "PASSWORD";

	private static final int sLoader_Authenticate = 1;

	@InjectView(R.id.activity_login_usernameET) 		private EditText mUsername;
	@InjectView(R.id.activity_login_passwordET) 		private EditText mPassword;
	@InjectView(R.id.activity_login_buttonNewAccount)	private Button mNewAccount;
	@InjectView(R.id.activity_login_mainlayout)			private LinearLayout mMainLayout;
	@InjectView(R.id.activity_login_progressbar)		private ProgressBar mProgressBar;

	@InjectResource(R.string.app_account)				private String accountName;
	@InjectResource(R.string.activity_login_error_empty)private String errorEmpty;

	@Inject private AccountManager mAccountManager;

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {

		//Basic setup
		super.onCreate(savedInstanceState);

		//Set view listeners and callbacks
		mNewAccount.setOnClickListener(this);
	}

	@Override
	public void onClick(View v) {

		//Get username and password
		final String username = mUsername.getText().toString();
		final String password = mPassword.getText().toString();

		final boolean isUsernameEmpty = TextUtils.isEmpty(username);
		final boolean isPasswordEmpty = TextUtils.isEmpty(password);

		//Check if either field is empty
		if (isUsernameEmpty || isPasswordEmpty){

			if(isUsernameEmpty){
				this.mUsername.setError(errorEmpty);
			}

			if(isPasswordEmpty){
				this.mPassword.setError(errorEmpty);
			}
			MessageDialog.showMessageDialog(getSupportFragmentManager(), R.string.activity_login_error_empty);
			return;
		}

		//Execute Authentication mechanism
		final Bundle extras = new Bundle();
		extras.putString(sKey_Username, username);
		extras.putString(sKey_Password, password);

		this.getSupportLoaderManager().restartLoader(sLoader_Authenticate, extras, this).forceLoad();
	}

	public void completeLogin(int company_id, int client_id){

		//Try to create account
		final Account account = new Account(this.mUsername.getText().toString(), accountName);
		final boolean accountCreated = this.mAccountManager.addAccountExplicitly(account, this.mPassword.getText().toString(), null);

		if (accountCreated){

			//Save Data
			final String password = this.mPassword.getText().toString();
			this.mAccountManager.setUserData(account, Authenticator.sPrefKey_Password, password);
			this.mAccountManager.setUserData(account, Authenticator.sPrefKey_ClientId, String.valueOf(client_id));
			this.mAccountManager.setUserData(account, Authenticator.sPrefKey_CompanyId, String.valueOf(company_id));

			//Manually Activate Sync
			final String authority = this.getString(R.string.app_authority);
			ContentResolver.setIsSyncable(account, authority, 1);
			ContentResolver.setSyncAutomatically(account, authority, true);

			//In case we have to return data...
			Bundle extras = getIntent().getExtras();
			if (extras != null){

				//Save Account
				AccountAuthenticatorResponse response = extras.getParcelable(AccountManager.KEY_ACCOUNT_AUTHENTICATOR_RESPONSE);
				Bundle result = new Bundle();
				result.putString(AccountManager.KEY_ACCOUNT_NAME, this.mUsername.getText().toString());
				result.putString(AccountManager.KEY_ACCOUNT_TYPE, accountName);
				response.onResult(result);
			}
		}

		this.finish();

	}

	@Override
	public Loader<JSONObject> onCreateLoader(int arg0, Bundle arg1) {
		if (arg0 == sLoader_Authenticate){
			arg1 = Preconditions.checkNotNull(arg1, "Bundle is null!");
			final String username = arg1.getString(sKey_Username);
			final String password = arg1.getString(sKey_Password);

			this.switchLayout(true);

			return new AuthTokenLoader(this, username, password);
		}

		return null;
	}

	@Override
	public void onLoadFinished(Loader<JSONObject> arg0, JSONObject arg1) {

		//Get the data
		String token = null;
		int company_id = -1;
		int client_id = -1;
		
		if (arg1 != null){
			try{
				//get the token
				token = AuthTokenLoader.getTokenFromJsonObject(arg1);

				//Get the rest of the required data
				final JSONObject user = arg1.getJSONArray("clients").getJSONObject(0);
				company_id = user.getInt("company_id");
				client_id = user.getInt("id");

				//check if login successful...
				if ((token != null &&!TextUtils.isEmpty(token)) && (company_id >= 0 && client_id >= 0) ){

					//Login Successful
					completeLogin(company_id, client_id);
					return;
				}

			}catch (JSONException e){
				e.printStackTrace();
			}
		}

		//Login Failed
		Toast.makeText(this, R.string.activity_login_error, Toast.LENGTH_LONG).show();
		this.switchLayout(false);

	}

	@Override
	public void onLoaderReset(Loader<JSONObject> arg0) {
		this.switchLayout(false);
	}

	private void switchLayout(final boolean pShowProgressBar){
		if (pShowProgressBar){
			this.mMainLayout.setVisibility(View.GONE);
			this.mProgressBar.setVisibility(View.VISIBLE);
		}

		else{
			this.mMainLayout.setVisibility(View.VISIBLE);
			this.mProgressBar.setVisibility(View.GONE);
		}
	}

}
