package com.scipanama.photoUploader.activities;

import roboguice.inject.ContentView;
import roboguice.inject.InjectFragment;
import roboguice.inject.InjectResource;
import android.accounts.Account;
import android.accounts.AccountManager;
import android.content.Intent;

import com.actionbarsherlock.view.Menu;
import com.actionbarsherlock.view.MenuItem;
import com.github.rtyley.android.sherlock.roboguice.activity.RoboSherlockFragmentActivity;
import com.google.inject.Inject;
import com.scipanama.photoUploader.R;
import com.scipanama.photoUploader.dialogs.AboutDialog;
import com.scipanama.photoUploader.dialogs.NewReferenceDialog;
import com.scipanama.photoUploader.fragments.MainListFragment;

/**
 * @author zubietaroberto
 *
 */

@ContentView(R.layout.activity_main)
public class MainActivity extends RoboSherlockFragmentActivity {	
	
	@InjectFragment(R.id.activity_main_fragment_mainlist) 
	private MainListFragment mListFragment;
	
	@InjectResource(R.string.app_account)				
	private String mAccount;
	
	@Inject private AccountManager mManager;
	
	@Override
	protected void onResume() {
		
		super.onResume();
		
		//Get Account names
		final Account[] accounts = mManager.getAccounts();
		
		//Iterate through the existing accounts
		for (Account possibleAccount: accounts){
			
			//Is this the account we are looking for?
			if (possibleAccount.type.equalsIgnoreCase(mAccount)){
				return;
			}
		}
		
		//Account doesn't exist. Create a new one
		final Intent intent = new Intent(this, LoginActivity.class);
		this.startActivity(intent);		
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		
		//Create ActionBar menu
		this.getSupportMenuInflater().inflate(R.menu.activity_main, menu);
		return super.onCreateOptionsMenu(menu);
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		
		//Which button was clicked?
		switch(item.getItemId()){
		
		//New Reference
		case R.id.menu_main_add:
			final NewReferenceDialog nrd = new NewReferenceDialog();
			nrd.show(getSupportFragmentManager(), "new_reference_dialog");
			return true;
			
		//About Dialog
		case R.id.menu_main_about:
			final AboutDialog ad = new AboutDialog();
			ad.show(getSupportFragmentManager(), "about_dialog");
			return true;
			
		//Show Queve
		case R.id.menu_main_queve:
			this.startActionMode(this.mListFragment);
			return true;
		
		//Launch Preferences
		case R.id.menu_main_settings:
			final Intent intent = new Intent(this, PreferenceActivity.class);
			this.startActivity(intent);
			return true;
			
		//Button not recognized	
		default:
			return super.onOptionsItemSelected(item);
		}
		
	}

}
