package com.scipanama.photoUploader.auth;

import android.accounts.AbstractAccountAuthenticator;
import android.accounts.Account;
import android.accounts.AccountAuthenticatorResponse;
import android.accounts.AccountManager;
import android.accounts.NetworkErrorException;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;

import com.google.inject.Inject;
import com.scipanama.photoUploader.activities.LoginActivity;
import com.scipanama.photoUploader.json.AuthTokenLoader;

/**
 * Handles Application authentication
 * 
 * @author zubietaroberto
 *
 */

public class Authenticator extends AbstractAccountAuthenticator {

	private static final String TAG = "Authenticator";
	private static final String LOG_PREAMBLE = TAG.concat(" >===< ");

	public static final String sPrefKey_Password = "PASSWORD";
	public static final String sPrefKey_ClientId = "CLIENT_ID";
	public static final String sPrefKey_CompanyId = "COMPANY_ID";
	
	private Context mContext;
	
	@Inject
	public Authenticator(Context context) {
		super(context);
		
		this.mContext = context;
	}

	@Override
	public Bundle editProperties(AccountAuthenticatorResponse response,
			String accountType) {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public Bundle addAccount(AccountAuthenticatorResponse response,
			String accountType, String authTokenType,
			String[] requiredFeatures, Bundle options)
			throws NetworkErrorException {
		
		//Log
		Log.v(TAG, LOG_PREAMBLE.concat("addAccount()"));
		
		//Create intent to launch LoginActivity to create new Account
		final Intent intent = new Intent(this.mContext, LoginActivity.class);
		intent.putExtra(AccountManager.KEY_ACCOUNT_AUTHENTICATOR_RESPONSE, response);
		
		//Send the intent back
		Bundle reply = new Bundle();
		reply.putParcelable(AccountManager.KEY_INTENT, intent);
		return reply;
	}

	@Override
	public Bundle confirmCredentials(AccountAuthenticatorResponse response,
			Account account, Bundle options) throws NetworkErrorException {
		// TODO Auto-generated method stub
		return null; 
	}

	@Override
	public Bundle getAuthToken(AccountAuthenticatorResponse response,
			Account account, String authTokenType, Bundle options)
			throws NetworkErrorException {
		
		//Logging
		Log.v(TAG, LOG_PREAMBLE.concat("getAuthToken()"));
		
		//Request token
		final String password = AccountManager.get(mContext).getPassword(account);		
		final String token = AuthTokenLoader.downloadToken(account.name, password);
		
		//Have we received a token?
		if (token == null){
			throw new NetworkErrorException();
		}
		
		//Build response
		final Bundle bundle = new Bundle();
		bundle.putString(AccountManager.KEY_ACCOUNT_NAME, account.name);
		bundle.putString(AccountManager.KEY_ACCOUNT_TYPE, account.type);
		bundle.putString(AccountManager.KEY_AUTHTOKEN, token);
		
		return bundle;
	}

	@Override
	public String getAuthTokenLabel(String authTokenType) {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public Bundle updateCredentials(AccountAuthenticatorResponse response,
			Account account, String authTokenType, Bundle options)
			throws NetworkErrorException {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public Bundle hasFeatures(AccountAuthenticatorResponse response,
			Account account, String[] features) throws NetworkErrorException {
		// TODO Auto-generated method stub
		return null;
	}

}
