package com.scipanama.photoUploader.auth;

import java.util.ArrayList;

import roboguice.RoboGuice;
import roboguice.inject.InjectResource;
import android.accounts.Account;
import android.content.AbstractThreadedSyncAdapter;
import android.content.ContentProviderClient;
import android.content.Context;
import android.content.SharedPreferences;
import android.content.SyncResult;
import android.database.Cursor;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;
import android.os.Bundle;
import android.os.RemoteException;
import android.util.Log;

import com.google.inject.Inject;
import com.scipanama.photoUploader.R;
import com.scipanama.photoUploader.json.PhotoUploader;
import com.scipanama.photoUploader.platform.UriFunction;

/**
 * Called when syncing to server. This class handles the sync and upload.
 * 
 * @author zubietaroberto
 *
 */
public class PhotoSyncAdapter extends AbstractThreadedSyncAdapter{
	
	private static final String LOG = "SyncAdapter";
	private static final String LOG_PREAMBLE = LOG.concat(" >==< ");
	
	@InjectResource(R.string.pref_network_use3g) private String key;
	
	@Inject private PhotoUploader mUploader;
	@Inject private SharedPreferences mPreferences;
	@Inject private ConnectivityManager mConnectivityManager;

	public PhotoSyncAdapter(Context context, boolean autoInitialize) {
		super(context, autoInitialize);
		
		RoboGuice.injectMembers(context, this);
	}

	@Override
	public void onPerformSync(Account account, Bundle extras, String authority,
			ContentProviderClient provider, SyncResult syncResult) {
		
		Log.d(LOG, LOG_PREAMBLE.concat("onPerformSync()"));
		
		//Does the user permit uploads over other networks rather than WiFi?
		final boolean wifiOnly = mPreferences.getBoolean(key, false);
		
		if(wifiOnly){
			final NetworkInfo wifiStatus = mConnectivityManager.getNetworkInfo(ConnectivityManager.TYPE_WIFI);
			
			if(!wifiStatus.isConnected()){
				Log.w(LOG, LOG_PREAMBLE.concat("Upload Canceled: Not Allowed over 3G!"));
				return;
			}
			
		}
		
		//Query the provider
		final Cursor cursor;
		try {
			cursor = provider.query(UriFunction.QUEVE.getUri(), null, null, null, null);	
		} 
		
		//Content provider failed, try again later
		catch (RemoteException e1) {
			e1.printStackTrace();
			syncResult.delayUntil = 10;
			syncResult.stats.numIoExceptions++;
			return;
		}
		
		//Get the Reference List to Upload
		final ArrayList<String> list = new ArrayList<String>();
		while(cursor.moveToNext()){
			list.add(cursor.getString(1));
		}
		
		this.mUploader.upload(list, account);
		
		syncResult.stats.numUpdates++;
		
	}

}
