package com.scipanama.photoUploader.dialogs;

import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.content.DialogInterface.OnClickListener;
import android.os.Bundle;

import com.github.rtyley.android.sherlock.roboguice.fragment.RoboSherlockDialogFragment;
import com.google.inject.Inject;
import com.scipanama.photoUploader.R;
import com.scipanama.photoUploader.activities.GalleryActivity;
import com.scipanama.photoUploader.platform.FileInterface;

/**
 * Dialog that asks a user if he really wants to mark a reference for uploading. 
 * If he accepts, then this dialog marks it immediately. 
 * <b>Important:</b> the reference to be uploaded must be passed in a Bundle though the
 * setArguments() method.
 * 
 * @author zubietaroberto
 *
 */
public class ConfirmUploadDialog extends RoboSherlockDialogFragment implements OnClickListener {
	
	public static final String sReference = "REFERENCE";
	private String mReference = null;
	
	@Inject private FileInterface mFileInterface;

	@Override
	public Dialog onCreateDialog(Bundle savedInstanceState) {
		
		if (this.mReference == null) throw new IllegalArgumentException("No reference in UploadDialog!");
		
		final AlertDialog.Builder adb = new AlertDialog.Builder(getActivity());
		adb.setTitle(R.string.dialog_confirmupload_title);
		adb.setMessage(R.string.dialog_confirmupload_message);
		adb.setPositiveButton(android.R.string.ok, this);
		adb.setNegativeButton(android.R.string.cancel, this);
		
		return adb.create();
	}

	@Override
	public void setArguments(Bundle args) {
		super.setArguments(args);
		this.mReference = args.getString(sReference);
	}

	@Override
	public void onClick(DialogInterface dialog, int which) {
		
		//Order the activity to Upload the photo
		if (which == Dialog.BUTTON_POSITIVE){
			
			//Upload Reference
			final GalleryActivity activity = (GalleryActivity) getActivity();
			if (this.mFileInterface.markReferenceForUploading(mReference)){
				
				//Kill the activity
				activity.finish();
			}
		}
		
	}

}
