/**
 * 
 */
package com.scipanama.photoUploader.fragments;

import android.content.Intent;
import android.database.Cursor;
import android.os.Bundle;
import android.support.v4.app.LoaderManager;
import android.support.v4.app.LoaderManager.LoaderCallbacks;
import android.support.v4.content.CursorLoader;
import android.support.v4.content.Loader;
import android.support.v4.widget.CursorAdapter;
import android.support.v4.widget.SimpleCursorAdapter;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ListView;
import android.widget.TextView;

import com.actionbarsherlock.view.ActionMode;
import com.actionbarsherlock.view.ActionMode.Callback;
import com.actionbarsherlock.view.Menu;
import com.actionbarsherlock.view.MenuItem;
import com.github.rtyley.android.sherlock.roboguice.fragment.RoboSherlockListFragment;
import com.scipanama.photoUploader.R;
import com.scipanama.photoUploader.activities.GalleryActivity;
import com.scipanama.photoUploader.platform.UriFunction;
import com.scipanama.photoUploader.providers.PhotoUploadProvider;
/**
 * This Fragment represents the list in the main activity.
 * 
 * @author zubietaroberto
 *
 */
public class MainListFragment extends RoboSherlockListFragment
	implements LoaderCallbacks<Cursor>, Callback{
	
	private static final int LOADER_STORAGE = 1;
	private static final int LOADER_QUEVE = 2;
	
	private SimpleCursorAdapter mAdapter;
	private LoaderManager mLoaderManager;
	private boolean mIsActionModeActive = false;

	@Override
	public View onCreateView(LayoutInflater inflater, ViewGroup container,
			Bundle savedInstanceState) {
		return inflater.inflate(R.layout.fragment_mainlist, container, false);
	}

	@Override
	public void onViewCreated(View view, Bundle savedInstanceState) {
		super.onViewCreated(view, savedInstanceState);
		
		//Create Adapter
		this.mAdapter = new SimpleCursorAdapter(this.getActivity(), 
				android.R.layout.simple_list_item_1, null, 
				new String[] 	{ PhotoUploadProvider.sColumn_Reference }, 
				new int[] 		{ android.R.id.text1 }, 
				CursorAdapter.FLAG_REGISTER_CONTENT_OBSERVER);
		this.setListAdapter(mAdapter);
		
		//Start loading Cursor
		this.mLoaderManager = this.getSherlockActivity().getSupportLoaderManager();
	}

	@Override
	public void onResume() {
		super.onResume();
		
		//Force load
		this.mLoaderManager.restartLoader(LOADER_STORAGE, null, this);
	}

	@Override
	public boolean onCreateActionMode(ActionMode mode, Menu menu) {
		this.mLoaderManager.initLoader(LOADER_QUEVE, null, this);
		mode.setTitle(R.string.activity_main_queve_text);
		mode.setSubtitle(R.string.activity_main_queveTextView_text);
		
		this.mIsActionModeActive = true;
		return true;
	}

	@Override
	public boolean onPrepareActionMode(ActionMode mode, Menu menu) {
		return false;
	}

	@Override
	public boolean onActionItemClicked(ActionMode mode, MenuItem item) {
		return false;
	}

	@Override
	public void onDestroyActionMode(ActionMode mode) {
		this.mLoaderManager.initLoader(LOADER_STORAGE, null, this);
		this.mIsActionModeActive = false;
	}

	@Override
	public Loader<Cursor> onCreateLoader(int arg0, Bundle arg1) {
		
		//Default Value: load the storage 
		UriFunction function = UriFunction.STORAGE;
		
		switch(arg0){
		
		// In case we have to load the Upload Queve instead...
		case LOADER_QUEVE:
			function = UriFunction.QUEVE;
			break;
			
		}
		
		//Create Loader
		return new CursorLoader(this.getActivity(), function.getUri(), null, null, null, null);
	}

	@Override
	public void onLoadFinished(Loader<Cursor> arg0, Cursor arg1) {
		this.mAdapter.swapCursor(arg1);
	}

	@Override
	public void onLoaderReset(Loader<Cursor> arg0) {
		this.mAdapter.swapCursor(null);
	}

	@Override
	public void onListItemClick(ListView l, View v, int position, long id) {
		//Gallery doesn't work for Queve items, so deactivate it
		if (this.mIsActionModeActive){
			return;
		}

		//Get the reference of the checked item
		final Bundle response = new Bundle();
		response.putString(GalleryActivity.sKey_Reference, ((TextView) v).getText().toString());

		//Launch GalleryActivity
		final Intent intent = new Intent(this.getActivity(), GalleryActivity.class);
		intent.putExtras(response);
		this.startActivity(intent);
		super.onListItemClick(l, v, position, id);
	}
	

}
