package com.scipanama.photoUploader.json;

import static com.google.common.base.Preconditions.checkNotNull;

import java.io.BufferedOutputStream;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.SocketTimeoutException;
import java.net.URL;

import org.json.JSONException;
import org.json.JSONObject;

import roboguice.content.RoboAsyncTaskLoader;
import android.content.Context;
import android.os.Build;
import android.util.Log;

public class AuthTokenLoader extends RoboAsyncTaskLoader<JSONObject> {
	private static final String sLogInURL = "http://www.logisticgears.com/api/v1/users/sign_in.json";

	static public String downloadToken(String pUsername, String pPassword){

		//Check for the token

		final JSONObject response = authenticate(pUsername, pPassword);
		String result = null;
		try {
			result = getTokenFromJsonObject(response);
		} catch (JSONException e) {
			e.printStackTrace();
		}	

		return result;

	}


	private static JSONObject authenticate(String pUsername, String pPassword){

		HttpURLConnection conn = null;
		BufferedOutputStream bos = null;
		JSONObject result = null;

		try {
			//Create the JSON request
			final JSONObject root = new JSONObject();
			final JSONObject userData = new JSONObject();

			userData.put("password", pPassword);
			userData.put("email", pUsername);
			root.put("user", userData);

			String message = root.toString();

			// HTTP connection reuse which was buggy pre-froyo
			if (Build.VERSION.SDK_INT < Build.VERSION_CODES.FROYO) {
				System.setProperty("http.keepAlive", "false");
			}

			//Open Connection
			final URL url = new URL(sLogInURL);
			conn = (HttpURLConnection) url.openConnection();
			conn.setReadTimeout(10000);
			conn.setConnectTimeout(15000);
			conn.setRequestMethod("POST");
			conn.setDoInput(true);
			conn.setDoOutput(true);
			conn.setFixedLengthStreamingMode(message.getBytes().length);

			//Create HTTP Header
			conn.setRequestProperty("Content-Type", "application/json;charset=utf-8");

			//Open Connection
			conn.connect();

			//Send message
			bos = new BufferedOutputStream(conn.getOutputStream());
			bos.write(message.getBytes());
			bos.flush();

			//Parse String into JSON
			BufferedReader reader = new BufferedReader(new InputStreamReader(conn.getInputStream()));
			StringBuilder sb = new StringBuilder();

			String line = null;
			while ((line = reader.readLine()) != null) {
				sb.append(line + "\n");
			}
			//is.close();
			final String string = sb.toString();
			Log.v("AuthTokenLoader", "Response Received:" + string);
			result =  new JSONObject( string);
		}

		catch (SocketTimeoutException e){
			e.printStackTrace();
		}
		catch (Exception e){
			e.printStackTrace();
		}
		finally{
			if (conn != null){
				conn.disconnect();
			}
		}


		return result;

	}
	
	public static String getTokenFromJsonObject(JSONObject object) throws JSONException{
		return object.get("authentication_token").toString();
	}

	private String mUsername;
	private String mPassword;

	public AuthTokenLoader(Context context, final String pUsername, final String pPassword) {
		super(context);

		this.mUsername = checkNotNull(pUsername, "Username Null");
		this.mPassword = checkNotNull(pPassword, "Password Null");
	}

	@Override
	public JSONObject loadInBackground() {
		return authenticate(mUsername, mPassword);
	}

}
