package com.scipanama.photoUploader.json;

import java.io.File;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Locale;

import org.apache.http.HttpEntity;
import org.apache.http.HttpResponse;
import org.apache.http.ParseException;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.HttpClient;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.mime.MultipartEntity;
import org.apache.http.entity.mime.content.FileBody;
import org.apache.http.entity.mime.content.StringBody;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.util.EntityUtils;

import android.accounts.Account;
import android.accounts.AccountManager;
import android.accounts.AuthenticatorException;
import android.accounts.OperationCanceledException;
import android.content.Context;
import android.text.TextUtils;
import android.util.Log;

import com.google.inject.Inject;
import com.scipanama.photoUploader.auth.Authenticator;
import com.scipanama.photoUploader.platform.FileInterface;
import com.scipanama.photoUploader.platform.FileInterface.FileType;

public class PhotoUploader{

	private static final String LOG = "PhotoUploader";
	private static final String LOG_PREAMBLE = LOG.concat(" >==< ");

	private static final String sUploadURL = "http://www.logisticgears.com/api/v1/shipments.json";

	private static final SimpleDateFormat mDateFormat = new SimpleDateFormat("yyyy-MM-dd", Locale.US);


	@Inject private Context mContext;
	@Inject private AccountManager mAM;
	@Inject private FileInterface mFileInterface;

	public boolean upload(final List<String> mReferences, final Account account){

		//Invalidate AuthToken, so we can get a new one
		this.mAM.invalidateAuthToken(account.type, null);

		//Get Authtoken
		String token;
		try {
			token = this.mAM.blockingGetAuthToken(account, "", false);


			//Make sure we have the correct data
			if (token == null || TextUtils.isEmpty(token)){
				Log.w(LOG, LOG_PREAMBLE.concat("empty authtoken or name!!"));
				return false;
			}

			//Upload the references
			for (String reference: mReferences){
				final File fileRoot = new File(mFileInterface.getRootDirectory(FileType.UPLOADING), reference);
				uploadReference(fileRoot, token, account);
			}

			return true;
			
			//Operation Cancelled by User
		} catch (OperationCanceledException e) {
			Log.w(LOG, LOG_PREAMBLE.concat("Exception: Operation Cancelled!"));
			e.printStackTrace();
			return false;
			
			//Authentication Failed
		} catch (AuthenticatorException e) {
			Log.w(LOG, LOG_PREAMBLE.concat("Exception: Authentication Failed!"));
			e.printStackTrace();
			return false;
			
			//Network Exception
		} catch (IOException e) {
			Log.w(LOG, LOG_PREAMBLE.concat("Exception: Network Failure!"));
			e.printStackTrace();
			return false;
		}
	}

	private void uploadReference(final File pReference, final String pToken, final Account pAcc) 
			throws ClientProtocolException, IOException{
		
		//If the folder is empty, do nothing.
		if (pReference.list().length <= 0){
			Log.v(LOG, "Reference " + pReference.getName() + " is empty");
			pReference.delete();
			return;
		}

		//Build Multipart Entity
		final HttpClient httpClient = new DefaultHttpClient();
		final HttpPost httpPost = new HttpPost(sUploadURL);
		final MultipartEntity entity = new MultipartEntity();

		//Get Data
		final String reference_name = pReference.getName();
		final String date 			= mDateFormat.format(new Date());
		final String company_id 	= this.mAM.getUserData(pAcc, Authenticator.sPrefKey_CompanyId);
		final String client_id 		= this.mAM.getUserData(pAcc, Authenticator.sPrefKey_ClientId);
		final String description 	= "Subido por Iris";

		//Put Data in Entity
		entity.addPart("auth_token", 			new StringBody(pToken));
		entity.addPart("shipment[name]", 		new StringBody(reference_name));
		entity.addPart("shipment[date]",		new StringBody(date));
		entity.addPart("shipment[company_id]",	new StringBody(company_id));
		entity.addPart("shipment[client_id]", 	new StringBody(client_id));
		entity.addPart("shipment[description]", new StringBody(description));

		//Add the photos
		for(File photo: pReference.listFiles()){
			entity.addPart("shipment[photos_attributes][][pic]", new FileBody(photo));
		}
		httpPost.setEntity(entity);

		//Send
		final HttpResponse response = httpClient.execute(httpPost);

		//Get Response
		this.analizeResult(response);

		//Delete stuff
		for(File photo: pReference.listFiles()){
			photo.delete();
			
			//Delete Cache
			final File cache = new File(this.mContext.getCacheDir(), photo.getName());
			if (cache.exists()){
				cache.delete();
			}
		}
		pReference.delete();
	}

	private void analizeResult(final HttpResponse response) throws ParseException, IOException{
		/*switch(response.getStatusLine().getStatusCode()){
		
		//STATUS OK
		case 200:*/
			final HttpEntity entity = response.getEntity();
			if (entity != null){
				final String responseBody = EntityUtils.toString(entity);
				Log.v(LOG, responseBody);
			}
			else{
				Log.v(LOG, "No Answer from server...");
			}
			/*
			break;
			
		}*/
	}

}
