package com.scipanama.photoUploader.platform;

import java.io.File;
import java.util.ArrayList;

import roboguice.RoboGuice;

import android.app.Activity;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageView;

import com.google.inject.Inject;
import com.scipanama.photoUploader.R;
import com.scipanama.photoUploader.platform.FileInterface.FileType;

/**
 * Puts image thumbnails in the GalleryView
 * 
 * @author zubietaroberto
 *
 */


public class ImageAdapter extends BaseAdapter{

	private static final String LOG = "ImageAdapter";
	private static final String LOG_PREFACE = LOG.concat(" >==< ");

	private final ArrayList<File> mImages = new ArrayList<File>();
	private final Activity mParentActivity;
	private final String mReference;
	
	@Inject private FileInterface mFileInterface;
	
	public ImageAdapter(final Activity pContext, final String pReference) {
		RoboGuice.injectMembers(pContext, this);
		this.mParentActivity = pContext;
		this.mReference = pReference;
	}

	@Override
	public int getCount() {
		return mImages.size();
	}

	@Override
	public Object getItem(int position) {
		return mImages.get(position);
	}

	@Override
	public long getItemId(int position) {
		return position;
	}

	@Override
	public View getView(int position, View convertView, ViewGroup parent) {
		
		//Interaction interface
		ImageListener entity = null;
		
		//Are we creating a new view...
		if(convertView == null){
			
			//Create new View
			final LayoutInflater inf = mParentActivity.getLayoutInflater();
			convertView = inf.inflate(R.layout.gridview_image, parent, false);
			
			//Create a new interaction interface
			entity = new ImageListener((ImageView) convertView.findViewById(R.id.gridview_image_imageView));
			convertView.setTag(entity);
			
			RoboGuice.injectMembers(mParentActivity, entity);
		}
		
		//...Or are we recycling an existing one?
		else{
			entity = (ImageListener) convertView.getTag();
		}
		
		//Interact with the interaction interface
		entity.setImage(this.mImages.get(position));
		return convertView;
	}
	
	@Override
	public void notifyDataSetChanged() {
		Log.d(LOG, LOG_PREFACE.concat("reload()"));

		this.mImages.clear();

		//Get a list of pictures in this folder
		final File dir = mFileInterface.getReferenceDirectory(FileType.STORAGE, mReference);
		File[] files = dir.listFiles();

		//if there are no files...
		if (files == null){
			return;
		}

		//iterate through the photos
		for (File file: files){
			Log.d(LOG, LOG_PREFACE.concat("registering File: " + file.getName()));
			this.mImages.add(file);
		}

		super.notifyDataSetChanged();
	}
	
}
