package com.scipanama.photoUploader.platform;

import java.io.File;

import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.net.Uri;
import android.os.Handler;
import android.os.HandlerThread;
import android.os.Looper;
import android.os.Process;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.ImageView;

import com.google.inject.Inject;
import com.scipanama.photoUploader.R;

/**
 * This represents a single thumbnail in the GalleryActivity.
 * Just call setImage(File) and it will asynchronously load it.
 * 
 * @author zubietaroberto
 *
 */
public class ImageListener implements Runnable, OnClickListener {
	
	private static Handler sMainHandler = new Handler(Looper.getMainLooper());
	private static Handler sWorkerHandler = null;
	
	private final ImageView mImageView;
	private File mFile = null;
	private Bitmap mBitmap = null;
	
	@Inject private Context mContext;
	@Inject private FileInterface mFileInterface;

	public ImageListener(final ImageView pImageView){
		this.mImageView = pImageView;
		this.mImageView.setOnClickListener(this);
		
		if (ImageListener.sWorkerHandler == null){
			final HandlerThread thread = new HandlerThread("Image Loader Thread", Process.THREAD_PRIORITY_BACKGROUND);
			thread.start();
			sWorkerHandler = new Handler(thread.getLooper());
		}
	}

	@Override
	public void onClick(View v) {
		
		//Launch ImageView intent
		final Intent intent = new Intent();
		intent.setAction(Intent.ACTION_VIEW);
		intent.setDataAndType(Uri.fromFile(mFile), "image/*");
		mContext.startActivity(intent);
	}
	
	/**
	 * Changes the image displayed in the thumbnail
	 * 
	 * @param pFile
	 */
	public void setImage(final File pFile){
		this.mFile = pFile;
		
		//Set placeholder
		this.mImageView.setImageResource(R.drawable.gridview_image_background);
		
		//Offload the decoding to parallel thread
		sWorkerHandler.post(this);
	}

	@Override
	public void run() {
		//Is this the background thread...
		if(Thread.currentThread() !=  Looper.getMainLooper().getThread()){
			
			//Decode Image
			this.mBitmap = this.mFileInterface.getBitmapFromCache(mFile);;
			sMainHandler.post(this);
		}
		
		//... or are we on the UI thread?
		else{
			this.mImageView.setImageBitmap(mBitmap);
		}
	}

}
