package com.scipanama.photoUploader.providers;

import java.io.File;

import roboguice.content.RoboContentProvider;
import android.content.ContentResolver;
import android.content.ContentValues;
import android.content.UriMatcher;
import android.database.Cursor;
import android.database.MatrixCursor;
import android.database.MatrixCursor.RowBuilder;
import android.net.Uri;

import com.google.inject.Inject;
import com.scipanama.photoUploader.platform.FileInterface;
import com.scipanama.photoUploader.platform.FileInterface.FileType;
import com.scipanama.photoUploader.platform.UriFunction;

/**
 * Represents all the data stored in the device. Ideally, 
 * This would be merged with FileOperation and JoooidFunctions
 * 
 * @author zubietaroberto
 *
 */
public class PhotoUploadProvider extends RoboContentProvider {
	
	public static final String sColumn_Reference = "REFERENCE";
	public static final String sColumn_ID = "_id";
	
	public static final String[] sColumns = {
		sColumn_ID,
		sColumn_Reference
	};
	
	public static final String CONTENT_TYPE = ContentResolver.CURSOR_DIR_BASE_TYPE + "/photos";
	public static final String CONTENT_ITEM_TYPE = ContentResolver.CURSOR_ITEM_BASE_TYPE + "/photo";
	
	private UriMatcher mMatcher;
	private final int mKey_Storage = 1;
	private final int mKey_UploadQueve = 2;
	
	@Inject private FileInterface mFileInterface;

	@Override
	public boolean onCreate() {
		super.onCreate();
		
		//Initialize the matcher. 
		this.mMatcher = new UriMatcher(UriMatcher.NO_MATCH);
		this.mMatcher.addURI(UriFunction.sAuthority, UriFunction.STORAGE.getSignature(), this.mKey_Storage);
		this.mMatcher.addURI(UriFunction.sAuthority, UriFunction.QUEVE.getSignature(), this.mKey_UploadQueve);
		
		return true;
	}

	@Override
	public synchronized Cursor query(Uri uri, String[] projection, String selection,
			String[] selectionArgs, String sortOrder) {
		
		final MatrixCursor result = new MatrixCursor(sColumns);
		final File root;
		
		switch (this.mMatcher.match(uri)){
		
		case mKey_Storage:
			root = mFileInterface.getRootDirectory(FileType.STORAGE);
			break;
		case mKey_UploadQueve:
			root  = mFileInterface.getRootDirectory(FileType.UPLOADING);
			break;
		default:
			return null;
		}
		
		//This can happen if there's no external storage
		if(root == null){
			return result;
		}
		

		//In case the folder doesn't exist
		root.mkdirs();
		
		if (!root.exists() || !root.isDirectory()){
			return result;
		}
		
		int counter = 0;
		for (String reference: root.list()){
			final RowBuilder builder = result.newRow();
			builder.add(Integer.toString(counter));
			builder.add(reference);
			counter++;
		}
		
		return result;
	}

	@Override
	public String getType(Uri uri) {
		return PhotoUploadProvider.CONTENT_TYPE;
	}

	@Override
	public Uri insert(Uri uri, ContentValues values) {
		// TODO Auto-generated method stub
		return null;
	}

	@Override
	public int delete(Uri uri, String selection, String[] selectionArgs) {
		// TODO Auto-generated method stub
		return 0;
	}

	@Override
	public int update(Uri uri, ContentValues values, String selection,
			String[] selectionArgs) {
		// TODO Auto-generated method stub
		return 0;
	}
	
}
